@@ -82,16 +82,17 @@ sub delete_device {
 
   my $happy = 0;
   schema('netdisco')->txn_do(sub {
-    schema('netdisco')->resultset('UserLog')->create({
-      username => session('logged_in_user'),
-      userip => scalar eval {request->remote_address},
-      event => "Delete device ". $device->ip ." ($ip)",
-      details => $log,
-    });
-
     # will delete everything related too...
     schema('netdisco')->resultset('Device')
       ->search({ ip => $device->ip })->delete({archive_nodes => $archive});
+
+    schema('netdisco')->resultset('UserLog')->create({
+      username => session('logged_in_user'),
+      userip => scalar eval {request->remote_address},
+      event => (sprintf "Delete device %s", $device->ip),
+      details => $log,
+    });
+
     $happy = 1;
   });
 
@@ -115,13 +116,15 @@ sub renumber_device {
 
   my $happy = 0;
   schema('netdisco')->txn_do(sub {
+    $device->renumber($new_ip)
+      or die "cannot renumber to: $new_ip"; # rollback
+
     schema('netdisco')->resultset('UserLog')->create({
       username => session('logged_in_user'),
       userip => scalar eval {request->remote_address},
-      event => "Renumbered device from $ip to $new_ip",
+      event => (sprintf "Renumber device %s to %s", $device->ip, $new_ip),
     });
 
-    $device->renumber($new_ip);
     $happy = 1;
   });
 
@@ -171,17 +174,14 @@ Regular Expression in YAML format which will match the device DNS name, e.g.:
 
 =item *
 
-C<"model:regex"> - matched against the device model
-
-=item *
-
-C<"vendor:regex"> - matched against the device vendor
+C<"property:regex"> - matched against a device property, such as C<model> or C<vendor>
 
 =back
 
-To simply match all devices, use "C<any>" or IP Prefix "C<0.0.0.0/0>". All
-regular expressions are anchored (that is, they must match the whole string).
-To match no devices we recommend an entry of "C<localhost>" in the setting.
+To simply match all devices, use "C<any>" or IP Prefix "C<0.0.0.0/0>".
+Property regular expressions are anchored (that is, they must match the whole
+string). To match no devices we recommend an entry of "C<localhost>" in the
+setting.
 
 =cut
 
@@ -225,17 +225,14 @@ Regular Expression in YAML format which will match the device DNS name, e.g.:
 
 =item *
 
-C<"model:regex"> - matched against the device model
-
-=item *
-
-C<"vendor:regex"> - matched against the device vendor
+C<"property:regex"> - matched against a device property, such as C<model> or C<vendor>
 
 =back
 
-To simply match all devices, use "C<any>" or IP Prefix "C<0.0.0.0/0>". All
-regular expressions are anchored (that is, they must match the whole string).
-To match no devices we recommend an entry of "C<localhost>" in the setting.
+To simply match all devices, use "C<any>" or IP Prefix "C<0.0.0.0/0>".
+Property regular expressions are anchored (that is, they must match the whole
+string). To match no devices we recommend an entry of "C<localhost>" in the
+setting.
 
 =cut
 
